# relaynet_pytorch

PyTorch Implementation of ReLayNet. There are still some bugs and issues in the code, we are working on fixing them.

Coded by Abhijit Guha Roy and Shayan Siddiqui (https://github.com/shayansiddiqui)

If you use this code for any academic purpose, please cite:

A. Guha Roy, S. Conjeti, S.P.K.Karri, D.Sheet, A.Katouzian, C.Wachinger, and N.Navab, "ReLayNet: retinal layer and fluid segmentation of macular optical coherence tomography using fully convolutional networks," Biomed. Opt. Express 8, 3627-3642 (2017) 
Link: https://arxiv.org/abs/1704.02161

Enjoy!! :)
